@@ -1,4 +1,4 @@
-/*      $Id: xfwm4_plugin.c,v 1.83 2004/12/27 19:05:37 pollux Exp $
+/*      $Id: xfwm4_plugin.c 12289 2005-01-14 11:41:37Z pollux $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -953,21 +953,57 @@ keybinding_selection_changed (GtkTreeSelection * selection, gpointer data)
         {
             ThemeInfo *ti;
 
-            g_free (current_key_theme);
-            current_key_theme = new_key_theme;
-            mcs_manager_set_string (mcs_plugin->manager, "Xfwm/KeyThemeName", CHANNEL2, current_key_theme);
-            mcs_manager_notify (mcs_plugin->manager, CHANNEL2);
-            write_options (mcs_plugin);
-
             ti = find_theme_info_by_name (new_key_theme, keybinding_theme_list);
-            
+
             if (ti)
-            {
-	        loadtheme_in_treeview (ti, itf);
-                gtk_widget_set_sensitive (itf->treeview3, ti->user_writable);
-                gtk_widget_set_sensitive (itf->treeview4, ti->user_writable);
-		gtk_widget_set_sensitive (itf->del_button, ti->user_writable);
-            }
+	    {
+	        gchar *theme_file;
+
+	        theme_file = g_build_filename (ti->path, KEY_SUFFIX, KEYTHEMERC, NULL);
+	        if (g_file_test (theme_file, G_FILE_TEST_EXISTS))
+		{
+		    g_free (current_key_theme);
+		    current_key_theme = new_key_theme;
+		    mcs_manager_set_string (mcs_plugin->manager, "Xfwm/KeyThemeName", CHANNEL2, current_key_theme);
+		    mcs_manager_notify (mcs_plugin->manager, CHANNEL2);
+		    write_options (mcs_plugin);
+		    
+		    loadtheme_in_treeview (ti, itf);
+		    gtk_widget_set_sensitive (itf->treeview3, ti->user_writable);
+		    gtk_widget_set_sensitive (itf->treeview4, ti->user_writable);
+		    gtk_widget_set_sensitive (itf->del_button, ti->user_writable);
+		}
+		else
+		{
+		    g_warning ("The keytheme file doesn't exist !");
+
+		    /* refresh list */
+		    while (keybinding_theme_list)
+		      {
+			theme_info_free ((ThemeInfo *)keybinding_theme_list->data);
+			keybinding_theme_list = g_list_next (keybinding_theme_list);
+		      }
+		    g_list_free (keybinding_theme_list);
+		    
+		    g_free (current_key_theme);
+		    current_key_theme = g_strdup ("Default");
+		    keybinding_theme_list = NULL;
+		    keybinding_theme_list = read_themes (keybinding_theme_list, itf->treeview2, itf->scrolledwindow2,
+							 KEYBINDING_THEMES, current_key_theme);
+		    gtk_widget_set_sensitive (itf->treeview3, FALSE);
+		    gtk_widget_set_sensitive (itf->treeview4, FALSE);
+		    loadtheme_in_treeview (find_theme_info_by_name ("Default", keybinding_theme_list), itf);
+		    
+		    /* tell it to the mcs manager */
+		    mcs_manager_set_string (itf->mcs_plugin->manager, "Xfwm/KeyThemeName", CHANNEL2, current_key_theme);
+		    mcs_manager_notify (itf->mcs_plugin->manager, CHANNEL2);
+		    write_options (itf->mcs_plugin);
+		}
+
+		g_free (theme_file);
+	    }
+	    else
+	        g_warning ("Cannot find the keytheme !!");
         }
     }
 }
@@ -1861,6 +1897,7 @@ setup_dialog (Itf * itf)
     {
         g_warning ("Cannot find the keytheme !");
     }
+
     g_signal_connect (G_OBJECT (itf->xfwm4_dialog), "response", G_CALLBACK (cb_dialog_response), itf->mcs_plugin);
     g_signal_connect (G_OBJECT (itf->font_button), "clicked", G_CALLBACK (show_font_selection), itf);
     g_signal_connect (G_OBJECT (itf->click_focus_radio), "toggled", G_CALLBACK (cb_click_to_focus_changed), itf);
