@@ -1,4 +1,4 @@
-/*      $Id: events.c,v 1.297.2.1 2005/01/12 17:51:19 olivier Exp $
+/*      $Id: events.c 14291 2005-05-13 21:35:54Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -189,9 +189,9 @@ typeOfClick_event_filter (XEvent * xevent, gpointer data)
 static XfwmButtonClickType
 typeOfClick (ScreenInfo *screen_info, Window w, XEvent * ev, gboolean allow_double_click)
 {
-    int g = GrabSuccess;
     DisplayInfo *display_info = NULL;
     XfwmButtonClickData passdata;
+    gboolean g;
 
     g_return_val_if_fail (screen_info != NULL, XFWM_BUTTON_UNDEFINED);
     g_return_val_if_fail (ev != NULL, XFWM_BUTTON_UNDEFINED);
@@ -199,13 +199,13 @@ typeOfClick (ScreenInfo *screen_info, Window w, XEvent * ev, gboolean allow_doub
     
     display_info = screen_info->display_info;    
     XFlush (display_info->dpy);
-    g = XGrabPointer (display_info->dpy, screen_info->gnome_win, 
-                      FALSE, DBL_CLICK_GRAB, GrabModeAsync,
-                      GrabModeAsync, None, None, ev->xbutton.time);
-    if (g != GrabSuccess)
+    g = myScreenGrabPointer (screen_info, DBL_CLICK_GRAB, None, ev->xbutton.time);
+
+    if (!g)
     {
         TRACE ("grab failed in typeOfClick");
         gdk_beep ();
+        myScreenUngrabPointer (screen_info, ev->xbutton.time);
         return XFWM_BUTTON_UNDEFINED;
     }
 
@@ -228,7 +228,7 @@ typeOfClick (ScreenInfo *screen_info, Window w, XEvent * ev, gboolean allow_doub
     xfce_pop_event_filter (display_info->xfilter);
     TRACE ("leaving typeOfClick loop");
 
-    XUngrabPointer (display_info->dpy, myDisplayGetCurrentTime (display_info));
+    myScreenUngrabPointer (screen_info, myDisplayGetCurrentTime (display_info));
     XFlush (display_info->dpy);
     return (XfwmButtonClickType) passdata.clicks;
 }
@@ -482,7 +482,7 @@ handleKeyPress (DisplayInfo *display_info, XKeyEvent * ev)
                 clientClose (c);
                 break;
             case KEY_HIDE_WINDOW:
-                if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_HAS_BORDER) && CLIENT_CAN_HIDE_WINDOW (c))
+                if (CLIENT_CAN_HIDE_WINDOW (c))
                 {
                     clientHide (c, c->win_workspace, TRUE);
                 }
@@ -500,7 +500,7 @@ handleKeyPress (DisplayInfo *display_info, XKeyEvent * ev)
                 clientToggleShaded (c);
                 break;
             case KEY_STICK_WINDOW:
-                if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_HAS_BORDER) && CLIENT_CAN_STICK_WINDOW(c))
+                if (CLIENT_CAN_STICK_WINDOW(c))
                 {
                     clientToggleSticky (c, TRUE);
                     frameDraw (c, FALSE, FALSE);
@@ -1587,6 +1587,7 @@ handleFocusOut (DisplayInfo *display_info, XFocusChangeEvent * ev)
         if ((c) && (c == clientGetFocus ()))
         {
             TRACE ("focus lost from \"%s\" (0x%lx)", c->name, c->window);
+            clientPassGrabMouseButton (NULL);
             clientUpdateFocus (c->screen_info, NULL, NO_FOCUS_FLAG);
             /* Clear timeout */
             clear_timeout ();
