@@ -1,4 +1,4 @@
-/*      $Id: focus.c,v 1.43 2004/12/30 22:08:37 olivier Exp $
+/*      $Id: focus.c 14226 2005-05-08 21:16:28Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -109,11 +109,15 @@ clientFocusTop (ScreenInfo *screen_info, int layer)
     top_client = clientGetTopMostFocusable (screen_info, layer, NULL);
     if (top_client.prefered)
     {
-        clientSetFocus (screen_info, top_client.prefered, CurrentTime, NO_FOCUS_FLAG);
+        clientSetFocus (screen_info, top_client.prefered, 
+                        myDisplayGetCurrentTime (screen_info->display_info), 
+                        NO_FOCUS_FLAG);
     }
     else
     {
-        clientSetFocus (screen_info, top_client.highest, CurrentTime, NO_FOCUS_FLAG);
+        clientSetFocus (screen_info, top_client.highest, 
+                        myDisplayGetCurrentTime (screen_info->display_info), 
+                        NO_FOCUS_FLAG);
     }
 }
 
@@ -150,6 +154,7 @@ clientFocusNew(Client * c)
         }
     }
 
+    clientGrabMouseButton (c);
     if (give_focus || FLAG_TEST(c->flags, CLIENT_FLAG_STATE_MODAL))
     {
         if (client_focus)
@@ -159,7 +164,13 @@ clientFocusNew(Client * c)
                 clientRaise (c);
             }
         }
-        clientSetFocus (c->screen_info, c, CurrentTime, FOCUS_IGNORE_MODAL);
+        clientSetFocus (screen_info, c, 
+#if 0
+                        myDisplayGetCurrentTime (display_info), 
+#else
+                        CurrentTime, 
+#endif
+                        FOCUS_IGNORE_MODAL);
     }
     else
     {
@@ -202,6 +213,7 @@ clientSelectMask (Client * c, int mask, int type)
     {
         return TRUE;
     }
+
     return FALSE;
 }
 
@@ -289,7 +301,6 @@ clientPassFocus (ScreenInfo *screen_info, Client *c, Client *exclude)
                    for group, so it safe to use clientGetTransient because 
                    it's really what we want...
                  */
-
                 c2 = clientGetTransient (c);
                 if (c2 && FLAG_TEST(c2->xfwm_flags, XFWM_FLAG_VISIBLE))
                 {
@@ -301,10 +312,7 @@ clientPassFocus (ScreenInfo *screen_info, Client *c, Client *exclude)
             else
             {
                 c2 = clientGetNext (c, 0);
-                /* Send focus back to the previous window only if it's on a different
-                   layer, to avoid sending focus back to a lowered window....
-                 */
-                if ((c2) && (c2->win_layer != c->win_layer))
+                if ((c2) && (c2->win_layer >= c->win_layer))
                 {
                     new_focus = c2;
                 }
@@ -319,7 +327,13 @@ clientPassFocus (ScreenInfo *screen_info, Client *c, Client *exclude)
     {
         new_focus = top_most.prefered ? top_most.prefered : top_most.highest;
     }
-    clientSetFocus (screen_info, new_focus, CurrentTime, FOCUS_IGNORE_MODAL | FOCUS_FORCE);
+    clientSetFocus (screen_info, new_focus, 
+#if 0
+                    myDisplayGetCurrentTime (screen_info->display_info), 
+#else
+                    CurrentTime, 
+#endif
+                    FOCUS_IGNORE_MODAL | FOCUS_FORCE);
 }
 
 gboolean
@@ -418,7 +432,7 @@ clientUpdateFocus (ScreenInfo *screen_info, Client * c, unsigned short flags)
         if (c)
         {
             clientAdjustFullscreenLayer (c2, FALSE);
-            clientRaise (c);
+            /* clientRaise (c); */
         }
         frameDraw (c2, FALSE, FALSE);
     }
