@@ -1,4 +1,4 @@
-/*      $Id: stacking.c,v 1.26 2004/12/05 23:02:28 olivier Exp $
+/*      $Id: stacking.c 12443 2005-03-27 19:32:37Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -240,18 +240,19 @@ clientAtPosition (ScreenInfo *screen_info, int x, int y, Client * exclude)
     Client *c = NULL;
     Client *c2 = NULL;
 
-    TRACE ("entering clientAtPos");
+    TRACE ("entering clientAtPosition");
 
     for (index = g_list_last (screen_info->windows_stack); index; index = g_list_previous (index))
     {
         c2 = (Client *) index->data;
-        if (clientSelectMask (c2, 0, WINDOW_NORMAL | WINDOW_DIALOG | WINDOW_MODAL_DIALOG) && (c2 != exclude))
+        if ((frameX (c2) < x) && (frameX (c2) + frameWidth (c2) > x)
+            && (frameY (c2) < y) && (frameY (c2) + frameHeight (c2) > y))
         {
-            if ((frameX (c2) < x) && (frameX (c2) + frameWidth (c2) > x)
-                && (frameY (c2) < y) && (frameY (c2) + frameHeight (c2) > y))
+            if (clientSelectMask (c2, 0, WINDOW_REGULAR_FOCUSABLE) 
+                && (c2 != exclude))
             {
                 c = c2;
-                break;
+        	break;
             }
         }
     }
@@ -444,6 +445,7 @@ clientLower (Client * c)
          */
         clientApplyStackList (screen_info);
         clientSetNetClientList (screen_info, display_info->atoms[NET_CLIENT_LIST_STACKING], screen_info->windows_stack);
+        clientPassGrabMouseButton (NULL);
         clientPassFocus (screen_info, c, NULL);
         if (screen_info->last_raise == c)
         {
