@@ -1,4 +1,4 @@
-/*      $Id: workspaces.c,v 1.93.2.2 2005/01/12 17:51:19 olivier Exp $
+/*      $Id: workspaces.c 13520 2005-04-10 20:33:31Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -237,7 +237,7 @@ workspaceSwitch (ScreenInfo *screen_info, int new_ws, Client * c2)
     int rx, ry, wx, wy;
     unsigned int mask;
     unsigned long data[1];
-
+    
     TRACE ("entering workspaceSwitch");
 
     if ((new_ws == screen_info->current_ws) && (screen_info->params->toggle_workspaces))
@@ -266,11 +266,8 @@ workspaceSwitch (ScreenInfo *screen_info, int new_ws, Client * c2)
         return;
     }
 
-    /* Grab the pointer to avoid side effects with EnterNotify events */
-    XGrabPointer (myScreenGetXDisplay (screen_info), screen_info->gnome_win, 
-                  FALSE, EnterWindowMask, GrabModeAsync,
-                  GrabModeAsync, None, None, myDisplayGetCurrentTime (display_info));
-    
+    myScreenGrabPointer (screen_info, EnterWindowMask, None, myDisplayGetCurrentTime (display_info));
+
     screen_info->previous_ws = screen_info->current_ws;
     screen_info->current_ws = new_ws;
     if (c2)
@@ -363,13 +360,19 @@ workspaceSwitch (ScreenInfo *screen_info, int new_ws, Client * c2)
         }
     }
 
-    /* Ungrab the pointer we grabbed before mapping/unmapping all windows */
-    XUngrabPointer (myScreenGetXDisplay (screen_info), myDisplayGetCurrentTime (display_info));
+    myScreenUngrabPointer (screen_info, myDisplayGetCurrentTime (display_info));
 
     if (new_focus)
     {
         clientSetFocus (new_focus->screen_info, new_focus, myDisplayGetCurrentTime (display_info), NO_FOCUS_FLAG);
     }
+#if 0
+    else
+    {
+        /* If we can't get a window to focus, just pick the one on top */
+        clientFocusTop (screen_info, WIN_LAYER_ABOVE_DOCK);
+    }
+#endif
 }
 
 void
